@@ -31,7 +31,7 @@ class PsmPy:
     ----------
     """
 
-    def __init__(self, data, treatment, indx, exclude=[], target='outcome'):
+    def __init__(self, data, treatment, indx, exclude=[], target='outcome', seed=42):
         # variables generated during matching
         # assign unique indices to test and control
         self.data = data.dropna(axis=0, how="all")  # drop all NAN rows
@@ -56,6 +56,7 @@ class PsmPy:
         self.controldf = self.dataIDindx[self.dataIDindx[treatment] == 0]
         self.treatmentn = len(self.treatmentdf)
         self.controln = len(self.controldf)
+        self.seed = seed
 
     def logistic_ps(self, balance=True):
         """ 
@@ -116,12 +117,13 @@ class PsmPy:
                     # self.majority_already_folded = majority_already_folded
                     # sample from the ones already folded over above to get major class of 20 for last fold:
                     majority_leftover2 = majority_already_folded.sample(
-                        n=need_2_sample_more_majorclass)
+                        n=need_2_sample_more_majorclass, random_state=self.seed)
                     # add the leftover to the additional that need to be sampled to get to 20
                     majority_leftover_all = pd.concat(
                         [majority_leftover1, majority_leftover2])
                     # sample a macthing 20 from the minor class
-                    minority_sample = minority.sample(n=20)
+                    minority_sample = minority.sample(
+                        n=20, random_state=self.seed)
                     joint_df = pd.concat(
                         [majority_leftover_all, minority_sample])
                     treatment = joint_df[self.treatment]
@@ -135,7 +137,8 @@ class PsmPy:
                     appended_data.append(df_cleaned)
                 else:
                     majority_extra = majority[majority_trunc_len:]
-                    minority_sample = minority.sample(n=majority_len_diff)
+                    minority_sample = minority.sample(
+                        n=majority_len_diff, random_state=self.seed)
                     joint_df = pd.concat([majority_extra, minority_sample])
                     treatment = joint_df[self.treatment]
                     df_cleaned = joint_df.drop([self.treatment], axis=1)
